@@ -1,26 +1,3 @@
-#' Forecasting Functions for Time Series and Linear Models
-#'
-#' Methods and tools for displaying and analysing univariate time series
-#' forecasts including exponential smoothing via state space models and
-#' automatic ARIMA modelling.
-#'
-#' \tabular{ll}{ Package: \tab forecast\cr Type: \tab Package\cr License: \tab
-#' GPL3\cr LazyLoad: \tab yes\cr }
-#'
-#' @docType package
-#' @name forecast-package
-#' @author Rob J Hyndman
-#'
-#' Maintainer: Rob.Hyndman@monash.edu
-#' @keywords package
-NULL # Instead of "_PACKAGE" to remove inclusion of \alias{forecast}
-# "_PACKAGE"
-
-## Generic forecast functions
-## Part of forecast and demography packages
-
-
-
 #' Forecasting time series
 #'
 #' \code{forecast} is a generic function for forecasting from time series or
@@ -102,78 +79,6 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{forecast}
 #' WWWusage %>% forecast %>% plot
 #' fit <- ets(window(WWWusage, end=60))
 #' fc <- forecast(WWWusage, model=fit)
-#'
-#' @export
-forecast <- function(object, ...) UseMethod("forecast")
-
-#' @rdname forecast
-#' @export
-forecast.default <- function(object, ...) forecast.ts(object, ...)
-
-## A function determining the appropriate period, if the data is of unknown period
-## Written by Rob Hyndman
-
-
-#' Find dominant frequency of a time series
-#'
-#' \code{findfrequency} returns the period of the dominant frequency of a time
-#' series. For seasonal data, it will return the seasonal period. For cyclic
-#' data, it will return the average cycle length.
-#'
-#' The dominant frequency is determined from a spectral analysis of the time
-#' series. First, a linear trend is removed, then the spectral density function
-#' is estimated from the best fitting autoregressive model (based on the AIC).
-#' If there is a large (possibly local) maximum in the spectral density
-#' function at frequency \eqn{f}, then the function will return the period
-#' \eqn{1/f} (rounded to the nearest integer). If no such dominant frequency
-#' can be found, the function will return 1.
-#'
-#' @param x a numeric vector or time series of class \code{ts}
-#' @return an integer value
-#' @author Rob J Hyndman
-#' @keywords ts
-#' @examples
-#'
-#' findfrequency(USAccDeaths) # Monthly data
-#' findfrequency(taylor) # Half-hourly data
-#' findfrequency(lynx) # Annual data
-#'
-#' @export
-findfrequency <- function(x) {
-  n <- length(x)
-  x <- as.ts(x)
-  # Remove trend from data
-  x <- residuals(tslm(x ~ trend))
-  # Compute spectrum by fitting ar model to largest section of x
-  n.freq <- 500
-  spec <- spec.ar(c(na.contiguous(x)), plot = FALSE, n.freq = n.freq)
-  if (max(spec$spec) > 10) # Arbitrary threshold chosen by trial and error.
-  {
-    period <- floor(1 / spec$freq[which.max(spec$spec)] + 0.5)
-    if (period == Inf) # Find next local maximum
-    {
-      j <- which(diff(spec$spec) > 0)
-      if (length(j) > 0) {
-        nextmax <- j[1] + which.max(spec$spec[(j[1] + 1):n.freq])
-        if (nextmax < length(spec$freq)) {
-          period <- floor(1 / spec$freq[nextmax] + 0.5)
-        } else {
-          period <- 1L
-        }
-      }
-      else {
-        period <- 1L
-      }
-    }
-  }
-  else {
-    period <- 1L
-  }
-
-  return(as.integer(period))
-}
-
-#' @rdname forecast
 #' @export
 forecast.ts <- function(object, h=ifelse(frequency(object) > 1, 2 * frequency(object), 10),
                         level=c(80, 95), fan=FALSE, robust=FALSE, lambda = NULL, biasadj = FALSE, find.frequency = FALSE,
@@ -234,6 +139,12 @@ forecast.ts <- function(object, h=ifelse(frequency(object) > 1, 2 * frequency(ob
   return(out)
 }
 
+#' @rdname forecast.ts
+#' @method forecast default
+#' @export
+forecast.default <- function(object, ...) forecast.ts(object, ...)
+
+#' @rdname forecast.ts
 #' @export
 print.forecast <- function(x, ...) {
   print(as.data.frame(x))
@@ -314,7 +225,6 @@ plotlmforecast <- function(object, PI, shaded, shadecols, col, fcol, pi.col, pi.
 }
 
 
-
 #' Forecast plot
 #'
 #' Plots historical data with forecasts and prediction intervals.
@@ -573,9 +483,15 @@ hfitted <- function(object, h=1, FUN=NULL, ...) {
   for (i in 1:(n - h))
   {
     refitarg[[1]] <- ts(x[1:i], start = tspx[1], frequency = tspx[3])
-    if (!is.null(object$xreg)) {
-      refitarg$xreg <- ts(object$xreg[1:i, ], start = tspx[1], frequency = tspx[3])
-      fcarg$xreg <- ts(object$xreg[(i + 1):(i + h), ], start = tspx[1] + i / tspx[3], frequency = tspx[3])
+    if(!is.null(object$xreg) & any(colnames(object$xreg)!="drift")){
+      if(any(colnames(object$xreg)=="drift")){
+        idx <- which(colnames(object$xreg)=="drift")
+        refitarg$xreg <- ts(object$xreg[1:i, -idx], start = tspx[1], frequency = tspx[3])
+        fcarg$xreg <- ts(object$xreg[(i + 1):(i + h), -idx], start = tspx[1] + i / tspx[3], frequency = tspx[3])
+      }else{
+        refitarg$xreg <- ts(object$xreg[1:i, ], start = tspx[1], frequency = tspx[3])
+        fcarg$xreg <- ts(object$xreg[(i + 1):(i + h), ], start = tspx[1] + i / tspx[3], frequency = tspx[3])
+      }
     }
     fcarg$object <- try(suppressWarnings(do.call(FUN, refitarg)), silent = TRUE)
     if (!is.element("try-error", class(fcarg$object))) {
@@ -626,7 +542,6 @@ subset.forecast <- function(x, ...) {
 }
 
 
-
 #' Is an object a particular forecast type?
 #'
 #' Returns true if the forecast object is of a particular type
